@@ -34,8 +34,8 @@ func Test_newConfig(t *testing.T) {
 				PrimitiveBackgroundColor:    0,
 				ContrastBackgroundColor:     0,
 				MoreContrastBackgroundColor: 0,
-				BorderColor:                 0,
-				TitleColor:                  0,
+				BorderColor:                 tcell.ColorGray,
+				TitleColor:                  tcell.ColorGray,
 				GraphicsColor:               0,
 				PrimaryTextColor:            0,
 				SecondaryTextColor:          0,
