@@ -6,13 +6,16 @@ import (
 	"fmt"
 	"html/template"
 	"io"
+	"os"
 	"sort"
 	"strconv"
 	"strings"
 	"sync"
+	"sync/atomic"
 	"time"
 
 	"github.com/gdamore/tcell/v2"
+	"github.com/moby/term"
 	"github.com/rivo/tview"
 )
 
@@ -42,6 +45,9 @@ type Viddy struct {
 	historyRows  map[int64]*HistoryRow
 	sync.RWMutex
 
+	// bWidth store current pty width.
+	bWidth atomic.Value
+
 	idList []int64
 
 	bodyView    *tview.TextView
@@ -63,6 +69,8 @@ type Viddy struct {
 	isNoTitle        bool
 	isShowDiff       bool
 	isEditQuery      bool
+	unfold           bool
+	pty              bool
 
 	query string
 
@@ -118,6 +126,8 @@ func NewViddy(conf *config) *Viddy {
 		isShowDiff: conf.general.differences,
 		isNoTitle:  conf.general.noTitle,
 		isDebug:    conf.general.debug,
+		unfold:     conf.general.unfold,
+		pty:        conf.general.pty,
 
 		currentID:        -1,
 		latestFinishedID: -1,
@@ -150,7 +160,7 @@ func (v *Viddy) SetIsTimeMachine(b bool) {
 }
 
 func (v *Viddy) println(a ...interface{}) {
-	fmt.Fprintln(v.logView, a...)
+	_, _ = fmt.Fprintln(v.logView, a...)
 }
 
 func (v *Viddy) addSnapshot(s *Snapshot) {
@@ -162,7 +172,7 @@ func (v *Viddy) startRunner() {
 		v.addSnapshot(s)
 		v.queue <- s.id
 
-		_ = s.run(v.finishedQueue)
+		_ = s.run(v.finishedQueue, v.getBodyWidth(), v.pty)
 	}
 }
 
@@ -320,16 +330,15 @@ func (v *Viddy) renderSnapshot(id int64) error {
 }
 
 func (v *Viddy) UpdateStatusView() {
-	v.statusView.SetText(fmt.Sprintf("Time Machine: %s  Suspend: %s  Diff: %s",
-		convertToOnOrOff(v.isTimeMachine), convertToOnOrOff(v.isSuspend), convertToOnOrOff(v.isShowDiff)))
+	v.statusView.SetText(fmt.Sprintf("Suspend %s  Diff %s", convertToOnOrOff(v.isSuspend), convertToOnOrOff(v.isShowDiff)))
 }
 
 func convertToOnOrOff(on bool) string {
 	if on {
-		return "[green]ON [reset]"
+		return "[green]◯[reset]"
 	}
 
-	return "[red]OFF[reset]"
+	return "[red]◯[reset]"
 }
 
 func (v *Viddy) arrange() {
@@ -342,24 +351,19 @@ func (v *Viddy) arrange() {
 	flex := tview.NewFlex().SetDirection(tview.FlexRow)
 
 	if !v.isNoTitle {
-		flex.AddItem(
-			tview.NewFlex().SetDirection(tview.FlexColumn).
-				AddItem(v.intervalView, 10, 1, false).
-				AddItem(v.commandView, 0, 1, false).
-				AddItem(v.statusView, 45, 1, false).
-				AddItem(v.timeView, 21, 1, false),
-			3, 1, false)
+		title := tview.NewFlex().SetDirection(tview.FlexColumn).
+			AddItem(v.intervalView, 10, 1, false).
+			AddItem(v.commandView, 0, 1, false).
+			AddItem(v.timeView, 21, 1, false)
+
+		flex.AddItem(title, 3, 1, false)
 	}
 
 	body := tview.NewFlex().SetDirection(tview.FlexRow)
 	body.AddItem(v.bodyView, 0, 1, false)
 
-	if v.isEditQuery || v.query != "" {
-		body.AddItem(v.queryEditor, 1, 1, false)
-	}
-
-	middle := tview.NewFlex().SetDirection(tview.FlexColumn).
-		AddItem(body, 0, 1, false)
+	middle := tview.NewFlex().SetDirection(tview.FlexColumn)
+	middle.AddItem(body, 0, 1, false)
 
 	if v.isTimeMachine {
 		middle.AddItem(v.historyView, 21, 1, true)
@@ -369,6 +373,18 @@ func (v *Viddy) arrange() {
 		middle,
 		0, 1, false)
 
+	bottom := tview.NewFlex().SetDirection(tview.FlexColumn)
+
+	if v.isEditQuery || v.query != "" {
+		bottom.AddItem(v.queryEditor, 0, 1, false)
+	} else {
+		bottom.AddItem(tview.NewBox(), 0, 1, false)
+	}
+
+	bottom.AddItem(v.statusView, 18, 1, false)
+
+	flex.AddItem(bottom, 1, 1, false)
+
 	if v.showLogView {
 		flex.AddItem(v.logView, 10, 1, false)
 	}
@@ -380,19 +396,24 @@ func (v *Viddy) arrange() {
 func (v *Viddy) Run() error {
 	b := tview.NewTextView()
 	b.SetDynamicColors(true)
-	b.SetTitle("body")
 	b.SetRegions(true)
+	b.GetInnerRect()
+	b.SetWrap(!v.unfold)
 	v.bodyView = b
 
 	t := tview.NewTextView()
 	t.SetBorder(true).SetTitle("Time")
+	t.SetTitleAlign(tview.AlignLeft)
 	v.timeView = t
 
 	h := tview.NewTable()
-	h.SetBorder(true).SetTitle("History")
+	v.historyView = h
+	h.SetTitle("History")
+	h.SetTitleAlign(tview.AlignLeft)
+	h.SetBorder(true)
 	h.ScrollToBeginning()
 	h.SetSelectionChangedFunc(func(row, column int) {
-		c := h.GetCell(row, column)
+		c := v.historyView.GetCell(row, column)
 		id, err := strconv.ParseInt(c.Text, 10, 64)
 		if err == nil {
 			_ = v.renderSnapshot(id)
@@ -400,24 +421,23 @@ func (v *Viddy) Run() error {
 	})
 	h.SetSelectedStyle(tcell.StyleDefault.Background(tcell.ColorGray))
 
-	v.historyView = h
-
 	var cmd []string
 	cmd = append(cmd, v.cmd)
 	cmd = append(cmd, v.args...)
 
 	c := tview.NewTextView()
 	c.SetBorder(true).SetTitle("Command")
+	c.SetTitleAlign(tview.AlignLeft)
 	c.SetText(strings.Join(cmd, " "))
 	v.commandView = c
 
 	d := tview.NewTextView()
 	d.SetBorder(true).SetTitle("Every")
+	d.SetTitleAlign(tview.AlignLeft)
 	d.SetText(v.duration.String())
 	v.intervalView = d
 
 	s := tview.NewTextView()
-	s.SetBorder(true).SetTitle("Status")
 	s.SetDynamicColors(true)
 	v.statusView = s
 
@@ -434,6 +454,7 @@ func (v *Viddy) Run() error {
 	q := tview.NewInputField().SetLabel("/")
 	q.SetChangedFunc(func(text string) {
 		v.query = text
+		_ = v.renderSnapshot(v.currentID)
 	})
 	q.SetDoneFunc(func(key tcell.Key) {
 		v.isEditQuery = false
@@ -548,18 +569,23 @@ func (v *Viddy) Run() error {
 		return event
 	})
 
-	v.app = app
-
-	go v.diffQueueHandler()
-	go v.queueHandler()
-	go v.startRunner()
+	app.SetAfterDrawFunc(func(screen tcell.Screen) {
+		v.setBodyWidth()
+	})
 
 	v.UpdateStatusView()
 
 	app.EnableMouse(true)
 
+	v.app = app
 	v.arrange()
 
+	v.setBodyWidth()
+
+	go v.diffQueueHandler()
+	go v.queueHandler()
+	go v.startRunner()
+
 	return app.Run()
 }
 
@@ -640,7 +666,7 @@ var helpTemplate = `Press ESC to go back
    [::u]General[-:-:-]     
 
    Toggle time machine mode : [yellow]SPACE[-:-:-]
-   Toggle suspend execution : [yellow]SPACE[-:-:-]
+   Toggle suspend execution : [yellow]s[-:-:-]
    Toggle diff              : [yellow]d[-:-:-]
    Toggle header display    : [yellow]t[-:-:-]
    Toggle help view         : [yellow]?[-:-:-]
@@ -697,6 +723,19 @@ func formatKeyStroke(stroke KeyStroke) string {
 	return b.String()
 }
 
+func (v *Viddy) setBodyWidth() {
+	width := 80
+	if winsize, err := term.GetWinsize(os.Stdout.Fd()); err == nil {
+		width = int(winsize.Width)
+	}
+
+	v.bWidth.Store(width)
+}
+
+func (v *Viddy) getBodyWidth() int {
+	return v.bWidth.Load().(int)
+}
+
 func (v *Viddy) helpPage() string {
 	value := struct {
 		GoToPast       string
